import { CheckReachabilityOptions, RecursivePartial } from 'clientnode/type';
import { PluginHandler, PluginPromises } from 'web-node/type';
import { Configuration, ServicePromisesState } from './type';
/**
 * Launches an application server und triggers all some pluginable hooks on
 * an event.
 */
export declare class Nginx implements PluginHandler {
    /**
     * Start nginx's child process and return a Promise which observes this
     * service.
     * @param state - Application state.
     * @param state.configuration - Applications configuration.
     * @param state.configuration.applicationServer - Plugins configuration.
     * @param state.services - An object with stored service instances.
     *
     * @returns A mapping to promises which correspond to the plugin specific
     * continues services.
     */
    static loadService({ configuration: { applicationServer: configuration }, services }: ServicePromisesState): Promise<null | PluginPromises>;
    /**
     * Application will be closed soon.
     * @param state - Application state.
     * @param state.configuration - Applications configuration.
     * @param state.services - Application services.
     *
     * @returns Given object of services.
     */
    static shouldExit({ configuration, services }: ServicePromisesState): Promise<void>;
    /**
     * Check if a nginx server is currently (not) running.
     * @param serverConfiguration - Mutable by plugins extended configuration
     * object.
     * @param inverse - Boolean indicating if we should check for reachability
     * or un-reachability.
     * @param givenOptions - Tools reachability options to configure how to
     * check for reachability.
     *
     * @returns A promise which will be resolved if a request to given url has
     * (not) finished. Otherwise returned promise will be rejected.
     */
    static checkReachability(serverConfiguration: Configuration['applicationServer'], inverse?: boolean, givenOptions?: RecursivePartial<CheckReachabilityOptions>): Promise<Response | Error | null | Promise<Error | null>>;
}
export default Nginx;
